# combo - content management system
# Copyright (C) 2015  Entr'ouvert
#
# This program is free software: you can redistribute it and/or modify it
# under the terms of the GNU Affero General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Affero General Public License for more details.
#
# You should have received a copy of the GNU Affero General Public License
# along with this program.  If not, see <http://www.gnu.org/licenses/>.

from django.conf import settings
from django.conf.urls import patterns, include, url
from django.contrib import admin

from .urls_utils import decorated_includes, manager_required

from .public.views import login, logout
from .manager.urls import urlpatterns as combo_manager_urls

from . import plugins

urlpatterns = patterns('',
    url(r'^manage/', decorated_includes(manager_required,
        include(combo_manager_urls))),
    url(r'^admin/', include(admin.site.urls)),
    url(r'^logout/$', logout, name='auth_logout'),
    url(r'^login/$', login, name='auth_login'),
)

if 'mellon' in settings.INSTALLED_APPS:
    urlpatterns += patterns('', url(r'^accounts/mellon/', include('mellon.urls')))

# static and media files
from django.contrib.staticfiles.urls import staticfiles_urlpatterns
urlpatterns += staticfiles_urlpatterns()

from django.conf.urls.static import static
urlpatterns += static(settings.MEDIA_URL, document_root=settings.MEDIA_ROOT)

urlpatterns = plugins.register_plugins_urls(urlpatterns)

# other URLs are handled as public URLs
urlpatterns += patterns('', url(r'', include('combo.public.urls')))
